scxpand.util.io
===============

.. automodule:: scxpand.util.io

   
   .. rubric:: Functions

   .. autosummary::
   
      close_adata_file_safely
      ensure_directory_exists
      exponential_backoff_delay
      is_hdf5_error
      load_eval_indices
      open_adata_file_with_retry
      open_adata_multiprocessing_safe
      read_adata_slice_chunked
      read_adata_slice_direct
      read_adata_slice_sequential
      retry_hdf5_operation
      safe_read_adata_slice
      save_predictions_to_csv
   
   .. rubric:: Classes

   .. autosummary::
   
      IOSettings
   